summaryrefslogtreecommitdiff
path: root/connectivity/source/inc/java/tools.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'connectivity/source/inc/java/tools.hxx')
-rw-r--r--connectivity/source/inc/java/tools.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/connectivity/source/inc/java/tools.hxx b/connectivity/source/inc/java/tools.hxx
index 66f339247dfc..1efaa76a861b 100644
--- a/connectivity/source/inc/java/tools.hxx
+++ b/connectivity/source/inc/java/tools.hxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
#include <com/sun/star/beans/PropertyValue.hpp>
#include <com/sun/star/uno/Sequence.h>
-#ifndef JNI_H
#include <jni.h>
-#endif
#include "java/sql/SQLException.hxx"
#include <comphelper/uno3.hxx>
@@ -74,15 +73,15 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
/** return if a exception occured
@param pEnv
The native java env
@param _bClear
<TRUE/> if the execption should be cleared
@return
- <TRUE/> if an exception is occured
+ <TRUE/> if an exception is occurred
*/
- sal_Bool isExceptionOccured(JNIEnv *pEnv,sal_Bool _bClear);
+ sal_Bool isExceptionOccurred(JNIEnv *pEnv,sal_Bool _bClear);
jobject createByteInputStream(const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& x,sal_Int32 length);
jobject createCharArrayReader(const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& x,sal_Int32 length);
@@ -90,3 +89,4 @@ namespace connectivity
#endif // _CONNECTIVITY_JAVA_TOOLS_HXX_
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -74,15 +73,15 @@ namespace connectivity
::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > Map2XNameAccess(JNIEnv *pEnv,jobject _pMap);
jobject convertTypeMapToJavaMap(JNIEnv *pEnv,const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & _rMap);
- /** return if a exception occured
+ /** return if a exception occurred
The native java env